**************************************************************
FGMK - A interface to generate code, and develop 2d RPG Games.
**************************************************************

FGMK (Fan Game MaKer) is a PyQt tool to generate files that describe a 2D
TopDown RPG Game. A javascript engine is packed together to read that
description and run the game in a portable way.
